@@ -44,8 +44,8 @@
 
 use strict;
 
-BEGIN { unshift @INC,'/home/cdf/PerlCDF32_4/blib/arch',
-                     '/home/cdf/PerlCDF32_4/blib/lib'; }
+BEGIN { unshift @INC,'/home/liu/PerlCDF33_1/blib/arch',
+                     '/home/liu/PerlCDF33_1/blib/lib'; }
 use CDF;
 
 my $N_DIMS = 2;
@@ -161,7 +161,7 @@ print "\nTesting Perl-CDF Internal/C interface\n\n";
 # Create CDF. 
 #############################################################################
 # Uncomment the following line if you want to create a V2.7 CDF file.
-# CDF::CDFsetFileBackward(FILEBACKWARDon);
+#CDF::CDFsetFileBackward(1);
 
 my $id; my $status;
 $status = CDF::CDFlib(CREATE_, CDF_, "TEST",$numDims,\@dimSizes,\$id,
@@ -288,12 +288,12 @@ $status = CDF::CDFlib (CREATE_, CDF_, "TEST", $numDims, \@dimSizes, \$id,
 QuitCDF ("6.0", $status) if ($status < CDF_OK) ;
 
 # Uncomment the following lines if MD5 checksum option is needed.
-$status = CDF::CDFlib (PUT_, CDF_CHECKSUM_, MD5_CHECKSUM,
-                       NULL_);
-QuitCDF ("6.1", $status) if ($status < CDF_OK) ;
+#$status = CDF::CDFlib (PUT_, CDF_CHECKSUM_, MD5_CHECKSUM,
+#                       NULL_);
+#QuitCDF ("6.1", $status) if ($status < CDF_OK) ;
 # Or, use this way:
 #$status = CDF::CDFsetChecksum ($id, MD5_CHECKSUM);
-QuitCDF ("6.1", $status) if ($status < CDF_OK) ;
+#QuitCDF ("6.1", $status) if ($status < CDF_OK) ;
 
 #############################################################################
 # Create variables.
@@ -1056,12 +1056,11 @@ QuitCDF ("27.2", $status) if ($status < CDF_OK) ;
 #############################################################################
 my $chksum;
 
-#$status = CDF::CDFlib (GET_, CDF_CHECKSUM_, \$chksum,
-#                       NULL_);
-$status = CDF::CDFgetChecksum ($id, \$chksum);
+$status = CDF::CDFlib (GET_, CDF_CHECKSUM_, \$chksum,
+                       NULL_);
 QuitCDF ("28.0", $status) if ($status < CDF_OK) ;
 
-QuitCDF ("28.1", $chksum) if ($chksum != MD5_CHECKSUM) ;
+#QuitCDF ("28.1", $chksum) if ($chksum != MD5_CHECKSUM) ;
 
 #############################################################################
 # Close CDF.
@@ -1090,8 +1089,9 @@ my $epStringTrue = '13-Oct-1994 01:02:03.987';
 my $epString1True = '19941013.0431017';
 my $epString2True = '19941013010203';
 my $epString3True = '1994-10-13T01:02:03.987Z';
+my $epString4True = '1994-10-13T01:02:03.987';
 
-my ($epString, $epString1, $epString2, $epString3);
+my ($epString, $epString1, $epString2, $epString3, $epString4);
 
 CDF::encodeEPOCH ($epoch, $epString);
 QuitEPOCH ("30.0") if ($epString ne $epStringTrue);
@@ -1105,6 +1105,9 @@ QuitEPOCH ("30.2") if ($epString2 ne $epString2True);
 CDF::encodeEPOCH3 ($epoch, $epString3);
 QuitEPOCH ("30.3") if ($epString3 ne $epString3True);
 
+CDF::encodeEPOCH4 ($epoch, $epString4);
+QuitEPOCH ("30.4") if ($epString4 ne $epString4True);
+
 my $epochOut = CDF::parseEPOCH ($epString);
 QuitEPOCH ("31.0") if ($epochOut != $epoch) ;
 
@@ -1138,8 +1141,9 @@ my $ep16StringTrue = '13-Oct-1994 01:02:03.987.876.765.654';
 my $ep16String1True = '19941013.043101711536640';
 my $ep16String2True = '19941013010203';
 my $ep16String3True = '1994-10-13T01:02:03.987.876.765.654Z';
+my $ep16String4True = '1994-10-13T01:02:03.987876765654';
 
-my ($ep16String, $ep16String1, $ep16String2, $ep16String3);
+my ($ep16String, $ep16String1, $ep16String2, $ep16String3, $ep16String4);
 
 CDF::encodeEPOCH16 (\@epoch16, $ep16String);
 QuitEPOCH ("40.0") if ($ep16String ne $ep16StringTrue);
@@ -1154,6 +1158,9 @@ QuitEPOCH ("40.2") if ($ep16String2 ne $ep16String2True);
 CDF::encodeEPOCH16_3 (\@epoch16, $ep16String3);
 QuitEPOCH ("40.3") if ($ep16String3 ne $ep16String3True);
 
+CDF::encodeEPOCH16_4 (\@epoch16, $ep16String4);
+QuitEPOCH ("40.4") if ($ep16String4 ne $ep16String4True);
+
 my @epoch16Out;
 $retco = CDF::parseEPOCH16 ($ep16String, \@epoch16Out);
 QuitEPOCH ("41.0") if ($epoch16Out[0] != $epoch16[0]) ;
